@@ -52,6 +52,11 @@ class QLProfile():
     def get_profile_page(nick, profile_request_type):
         return requests.get(QLProfile.PROFILE_PAGE_PATTERN % (profile_request_type, nick))
 
+    @staticmethod
+    def is_player_exists(nick):
+        return True if requests.post('http://quakelive.com/register/verify/nametag',
+                                     data={"value": nick}).json()['ECODE'] == -1 else False
+
 
 class QLProfileRequestType():
     SUMMARY = 'summary'
@@ -72,27 +77,30 @@ class QLProfileSummaryParser(QLProfileParser):
         QLProfileParser.__init__(self)
 
     def parse_html(self, page):
-        page = page.text
-        page = page.replace('&hellip;', '...')
-        tree = ET.fromstring(page)
-        profile_title = tree.findall('.//h1[@class="profile_title"]')[0]
-        profile_title_flag_image = profile_title[0].attrib['src']
-        profile_title_name = tree[0].text
-        profile_player_body_image = tree.findall('.//div[@class="prf_imagery"]')[0][0].attrib['style']
+        try:
+            page = page.text
+            page = page.replace('&hellip;', '...') # TODO fix parse error with all html  entities
+            tree = ET.fromstring(page)
+            profile_title = tree.findall('.//h1[@class="profile_title"]')[0]
+            profile_title_flag_image = profile_title[0].attrib['src']
+            profile_title_name = tree[0].text
+            profile_player_body_image = tree.findall('.//div[@class="prf_imagery"]')[0][0].attrib['style']
 
-        matches = re.search('background: url\((.*)\)', profile_player_body_image)
-        if matches:
-            profile_player_body_image = matches.group(1)
-        else:
-            profile_player_body_image = ''
-        stats = tree.findall('.//div[@class="prf_vitals"]/p')[0]
-        text = ET.tostring(stats).decode()
-        text = text.replace('\\n', '')
-        text = text.replace('\\t', '')
+            matches = re.search('background: url\((.*)\)', profile_player_body_image)
+            if matches:
+                profile_player_body_image = matches.group(1)
+            else:
+                profile_player_body_image = ''
+            stats = tree.findall('.//div[@class="prf_vitals"]/p')[0]
+            text = ET.tostring(stats).decode()
+            text = text.replace('\\n', '')
+            text = text.replace('\\t', '')
 
-        return {
-            'name': profile_title_name,
-            'flag': profile_title_flag_image,
-            'model': profile_player_body_image,
-            'summary': text
-        }
\ No newline at end of file
+            return {
+                'name': profile_title_name,
+                'flag': profile_title_flag_image,
+                'model': profile_player_body_image,
+                'summary': text
+            }
+        except BaseException as e:
+            return None
\ No newline at end of file
