@@ -31,8 +31,12 @@ page = qlprofile.QLProfile.get_profile_page('fx', qlprofile.QLProfileRequestType
 
 
 import xml.etree.ElementTree as ET
-page = page.replace('&hellip;', '...')
-tree = ET.fromstring(page)
+# page = page.replace('&hellip;', '...')
+parser = ET.XMLParser()
+parser.parser.UseForeignDTD(True)
+tree = ET.fromstring(page, parser=parser)
+# tree = ET.fromstring(page)
+
 profile_title = tree.findall('.//h1[@class="profile_title"]')[0]
 profile_title_flag_image = profile_title[0].attrib['src']
 profile_title_name = tree[0].text
@@ -48,3 +52,6 @@ text = text.replace('\\t', '')
 print('test: ' + text)
 
 
+print('fx exists?: %s' % qlprofile.QLProfile.is_player_exists('fx'))
+print('sadfdsaop23j42 exists?: %s' % qlprofile.QLProfile.is_player_exists('sadfdsaop23j42'))
+
